@@ -553,7 +553,7 @@ class StreamlitSherpaClient:
             description: str = None,
             nature: str = "sequence_labelling",
     ):
-        shortuuid.set_alphabet("123456789abcdefghijkmnopqrstuvwxyz_")
+        shortuuid.set_alphabet("123456789abcdefghijkmnopqrstuvwxyz")
         pname = f"{prefix}_" + shortuuid.uuid()[: (16 - len(prefix))]
         r = create_project.sync_detailed(
             client=self.client,
