@@ -4,20 +4,12 @@ from typing import Tuple, List, Optional
 
 import streamlit as st
 from PIL import Image
-from annotated_text import span, annotation
+from annotated_text import annotation
+from annotated_text.util import span, rem, div, em, px
 from bs4 import BeautifulSoup
-from htbuilder import H, styles, HtmlElement
-from htbuilder.units import unit
+from htbuilder import styles, HtmlElement
 from sherpa_client.models import Document, ProjectBean
 
-# Only works in 3.7+: from htbuilder import div, span
-
-div = H.div
-# Only works in 3.7+: from htbuilder.units import px, rem, em
-px = unit.px
-rem = unit.rem
-em = unit.em
-
 
 def ProjectBean_hash(self):
     return self.name
@@ -39,12 +31,13 @@ HASH_FUNCS = {
     "sherpa_streamlit.sherpa.StreamlitSherpaClient": StreamlitSherpaClient_hash,
     "sherpa_streamlit.sherpa.ExtendedAnnotator": ExtendedAnnotator_hash,
     "sherpa_client.models.ProjectBean": ProjectBean_hash,
-    "sherpa_client.models.Document": Document_hash
+    "sherpa_client.models.Document": Document_hash,
 }
 
 
 def get_client(token: str):
     from sherpa_streamlit.sherpa import StreamlitSherpaClient
+
     return StreamlitSherpaClient.from_token(token)
 
 
@@ -63,22 +56,51 @@ def get_cached_sample_doc(token: str, project: str, debug: bool = False) -> Docu
 
 
 @st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
-def get_cached_annotators(token: str, project: str, annotator_types: Tuple[str] = None,
-                          favorite_only: bool = False, debug: bool = False):
+def get_cached_annotators(
+    token: str,
+    project: str,
+    annotator_types: Tuple[str] = None,
+    favorite_only: bool = False,
+    debug: bool = False,
+):
     if debug:
-        st.write("Cache miss: get_cached_annotators(", token, ",", project, ",", annotator_types, ",", favorite_only,
-                 ") ran")
+        st.write(
+            "Cache miss: get_cached_annotators(",
+            token,
+            ",",
+            project,
+            ",",
+            annotator_types,
+            ",",
+            favorite_only,
+            ") ran",
+        )
     return get_client(token).get_annotators(project, annotator_types, favorite_only)
 
 
 @st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
-def get_cached_annotator_by_label(token: str, project: str, label: str,
-                                  annotator_types: Tuple[str] = None,
-                                  favorite_only: bool = False, debug: bool = False):
+def get_cached_annotator_by_label(
+    token: str,
+    project: str,
+    label: str,
+    annotator_types: Tuple[str] = None,
+    favorite_only: bool = False,
+    debug: bool = False,
+):
     if debug:
-        st.write("Cache miss: get_cached_annotator_by_label(", token, ",", project, ",", label, ",",
-                 annotator_types, ",",
-                 favorite_only, ") ran")
+        st.write(
+            "Cache miss: get_cached_annotator_by_label(",
+            token,
+            ",",
+            project,
+            ",",
+            label,
+            ",",
+            annotator_types,
+            ",",
+            favorite_only,
+            ") ran",
+        )
     annotators = get_cached_annotators(token, project, annotator_types, favorite_only)
     for ann in annotators:
         if ann.label == label:
@@ -87,7 +109,9 @@ def get_cached_annotator_by_label(token: str, project: str, label: str,
 
 
 @st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
-def get_cached_project_by_label(token: str, label: str, debug: bool = False) -> Optional[ProjectBean]:
+def get_cached_project_by_label(
+    token: str, label: str, debug: bool = False
+) -> Optional[ProjectBean]:
     if debug:
         st.write("Cache miss: get_cached_project_by_label(", token, ",", label, ") ran")
     projects = get_cached_projects(token)
@@ -100,7 +124,7 @@ def get_cached_project_by_label(token: str, label: str, debug: bool = False) ->
 @st.experimental_memo(suppress_st_warning=True)
 def get_logo():
     srcdir = Path(__file__).parent
-    image = Image.open(srcdir / 'kairntech-1000-Blockmark.png')
+    image = Image.open(srcdir / "kairntech-1000-Blockmark.png")
     return image
 
 
@@ -151,7 +175,7 @@ def clean_annotation(body, label="", background="#ddd", color="#333", **style):
 
     return span(
         style=styles(
-            border_style='solid',
+            border_style="solid",
             border_color=background,
             border_radius=rem(0.33),
             color=color,
@@ -161,7 +185,7 @@ def clean_annotation(body, label="", background="#ddd", color="#333", **style):
             white_space="normal",
             **style,
         ),
-        title=label
+        title=label,
     )(
         html.escape(body),
     )
@@ -210,14 +234,15 @@ def annotated_text(*args):
             line_height=rem(1.75),
             letter_spacing=em(0),
             white_space="pre-wrap",
-            overflow_x='auto',
+            overflow_x="auto",
             border=px(1),
             border_color="#e6e9ef",
-            border_style='solid',
+            border_style="solid",
             border_radius=rem(0.25),
             padding=rem(1.0),
-            margin_bottom=rem(2.5)
-        ))
+            margin_bottom=rem(2.5),
+        )
+    )
     # style="line-height: 1.75rem; letter-spacing: 0em; white-space: pre-wrap; overflow-x: auto; border: 1px solid #e6e9ef; border-radius: 0.25rem; padding: 1rem; margin-bottom: 2.5rem")
 
     for arg in args:
@@ -237,7 +262,7 @@ def annotated_text(*args):
 
 
 def clean_html(html: str):
-    soup = BeautifulSoup(html, 'html.parser')
+    soup = BeautifulSoup(html, "html.parser")
     return soup.get_text()
 
 
